# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/time_synchronization.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/time_synchronization.proto',
  package='blickfeld.protocol.status',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+blickfeld/status/time_synchronization.proto\x12\x19\x62lickfeld.protocol.status\x1a\x17\x62lickfeld/options.proto\"\xb1\x05\n\x13TimeSynchronization\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32\x34.blickfeld.protocol.status.TimeSynchronization.State\x12 \n\x12offset_from_master\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x41\n\x03ntp\x18\x03 \x01(\x0b\x32\x32.blickfeld.protocol.status.TimeSynchronization.NTPH\x00\x12\x41\n\x03ptp\x18\x04 \x01(\x0b\x32\x32.blickfeld.protocol.status.TimeSynchronization.PTPH\x00\x1a\xcf\x01\n\x03PTP\x12\x13\n\x05state\x18\x01 \x01(\tB\x04\xb0\xb5\x18\x01\x12\x16\n\x08\x63lock_id\x18\x02 \x01(\tB\x04\xb0\xb5\x18\x01\x12\x1b\n\rone_way_delay\x18\x03 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fslave_to_master\x18\x04 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fmaster_to_slave\x18\x05 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1c\n\x0eobserved_drift\x18\x06 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\"\n\x14last_packet_received\x18\x07 \x01(\tB\x04\xb0\xb5\x18\x01\x1a\x8c\x01\n\x03NTP\x12\x1e\n\x10\x66requency_offset\x18\x01 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x18\n\nrms_jitter\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0f\x61llan_deviation\x18\x03 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12,\n\x1e\x63lock_discipline_time_constant\x18\x04 \x01(\x02\x42\x04\xb0\xb5\x18\x01\">\n\x05State\x12\x0b\n\x07STOPPED\x10\x01\x12\x10\n\x0cINITIALIZING\x10\x02\x12\n\n\x06SYNCED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x0c\n\x04kind\x12\x04\xb0\xb5\x18\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])



_TIMESYNCHRONIZATION_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='blickfeld.protocol.status.TimeSynchronization.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCED', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=713,
  serialized_end=775,
)
_sym_db.RegisterEnumDescriptor(_TIMESYNCHRONIZATION_STATE)


_TIMESYNCHRONIZATION_PTP = _descriptor.Descriptor(
  name='PTP',
  full_name='blickfeld.protocol.status.TimeSynchronization.PTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_id', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.clock_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_way_delay', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.one_way_delay', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slave_to_master', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.slave_to_master', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_to_slave', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.master_to_slave', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observed_drift', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.observed_drift', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_packet_received', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.last_packet_received', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=568,
)

_TIMESYNCHRONIZATION_NTP = _descriptor.Descriptor(
  name='NTP',
  full_name='blickfeld.protocol.status.TimeSynchronization.NTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency_offset', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.frequency_offset', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rms_jitter', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.rms_jitter', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allan_deviation', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.allan_deviation', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_discipline_time_constant', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.clock_discipline_time_constant', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=711,
)

_TIMESYNCHRONIZATION = _descriptor.Descriptor(
  name='TimeSynchronization',
  full_name='blickfeld.protocol.status.TimeSynchronization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='blickfeld.protocol.status.TimeSynchronization.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_from_master', full_name='blickfeld.protocol.status.TimeSynchronization.offset_from_master', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ntp', full_name='blickfeld.protocol.status.TimeSynchronization.ntp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptp', full_name='blickfeld.protocol.status.TimeSynchronization.ptp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TIMESYNCHRONIZATION_PTP, _TIMESYNCHRONIZATION_NTP, ],
  enum_types=[
    _TIMESYNCHRONIZATION_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='blickfeld.protocol.status.TimeSynchronization.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\260\265\030\001'),
  ],
  serialized_start=100,
  serialized_end=789,
)

_TIMESYNCHRONIZATION_PTP.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION_NTP.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION.fields_by_name['state'].enum_type = _TIMESYNCHRONIZATION_STATE
_TIMESYNCHRONIZATION.fields_by_name['ntp'].message_type = _TIMESYNCHRONIZATION_NTP
_TIMESYNCHRONIZATION.fields_by_name['ptp'].message_type = _TIMESYNCHRONIZATION_PTP
_TIMESYNCHRONIZATION_STATE.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _TIMESYNCHRONIZATION.fields_by_name['ntp'])
_TIMESYNCHRONIZATION.fields_by_name['ntp'].containing_oneof = _TIMESYNCHRONIZATION.oneofs_by_name['kind']
_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _TIMESYNCHRONIZATION.fields_by_name['ptp'])
_TIMESYNCHRONIZATION.fields_by_name['ptp'].containing_oneof = _TIMESYNCHRONIZATION.oneofs_by_name['kind']
DESCRIPTOR.message_types_by_name['TimeSynchronization'] = _TIMESYNCHRONIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeSynchronization = _reflection.GeneratedProtocolMessageType('TimeSynchronization', (_message.Message,), {

  'PTP' : _reflection.GeneratedProtocolMessageType('PTP', (_message.Message,), {
    'DESCRIPTOR' : _TIMESYNCHRONIZATION_PTP,
    '__module__' : 'blickfeld.status.time_synchronization_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization.PTP)
    })
  ,

  'NTP' : _reflection.GeneratedProtocolMessageType('NTP', (_message.Message,), {
    'DESCRIPTOR' : _TIMESYNCHRONIZATION_NTP,
    '__module__' : 'blickfeld.status.time_synchronization_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization.NTP)
    })
  ,
  'DESCRIPTOR' : _TIMESYNCHRONIZATION,
  '__module__' : 'blickfeld.status.time_synchronization_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization)
  })
_sym_db.RegisterMessage(TimeSynchronization)
_sym_db.RegisterMessage(TimeSynchronization.PTP)
_sym_db.RegisterMessage(TimeSynchronization.NTP)


_TIMESYNCHRONIZATION_PTP.fields_by_name['state']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['clock_id']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['one_way_delay']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['slave_to_master']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['master_to_slave']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['observed_drift']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['last_packet_received']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['frequency_offset']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['rms_jitter']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['allan_deviation']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['clock_discipline_time_constant']._options = None
_TIMESYNCHRONIZATION.oneofs_by_name['kind']._options = None
_TIMESYNCHRONIZATION.fields_by_name['offset_from_master']._options = None
# @@protoc_insertion_point(module_scope)
