"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MessageHeader(google.protobuf.message.Message):
    """*
    Metadata for a Protobuf message.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROJECT_UUID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    project_uuid: typing.Text = ...
    """UUID of the project."""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of message construction."""
        pass
    project_name: typing.Text = ...
    """the name of the project as defined by the user"""

    def __init__(self,
        *,
        project_uuid : typing.Text = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        project_name : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"project_name",b"project_name",u"project_uuid",b"project_uuid",u"timestamp",b"timestamp"]) -> None: ...
global___MessageHeader = MessageHeader
