# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/object.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from bf_proto.percept.common import geometric_shapes_pb2 as bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2
from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/object.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"bf_proto/percept/data/object.proto\x12\x16\x62lickfeld.percept.data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.bf_proto/percept/common/geometric_shapes.proto\x1a&bf_proto/percept/common/geometry.proto\"\x95\x04\n\x06Object\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12,\n\x04pose\x18\x03 \x01(\x0b\x32\x1e.blickfeld.percept.common.Pose\x12:\n\x0flinear_velocity\x18\x04 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12;\n\x10\x61ngular_velocity\x18\x05 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12.\n\x05shape\x18\x06 \x01(\x0b\x32\x1f.blickfeld.percept.common.Shape\x12\x45\n\x0e\x63lassification\x18\x07 \x01(\x0b\x32-.blickfeld.percept.data.Object.Classification\x12,\n\x04path\x18\x08 \x03(\x0b\x32\x1e.blickfeld.percept.common.Pose\x1a\x81\x01\n\x0e\x43lassification\x12\x41\n\x05types\x18\x01 \x03(\x0b\x32\x32.blickfeld.percept.data.Object.Classification.Type\x1a,\n\x04Type\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\nconfidence\x18\x02 \x01(\x02J\x04\x08\x01\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_OBJECT_CLASSIFICATION_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='blickfeld.percept.data.Object.Classification.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.percept.data.Object.Classification.Type.id', index=0,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='blickfeld.percept.data.Object.Classification.Type.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=717,
)

_OBJECT_CLASSIFICATION = _descriptor.Descriptor(
  name='Classification',
  full_name='blickfeld.percept.data.Object.Classification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='blickfeld.percept.data.Object.Classification.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_CLASSIFICATION_TYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=717,
)

_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='blickfeld.percept.data.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blickfeld.percept.data.Object.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='blickfeld.percept.data.Object.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='blickfeld.percept.data.Object.pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='blickfeld.percept.data.Object.linear_velocity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='blickfeld.percept.data.Object.angular_velocity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='blickfeld.percept.data.Object.shape', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classification', full_name='blickfeld.percept.data.Object.classification', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='blickfeld.percept.data.Object.path', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_CLASSIFICATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=717,
)

_OBJECT_CLASSIFICATION_TYPE.containing_type = _OBJECT_CLASSIFICATION
_OBJECT_CLASSIFICATION.fields_by_name['types'].message_type = _OBJECT_CLASSIFICATION_TYPE
_OBJECT_CLASSIFICATION.containing_type = _OBJECT
_OBJECT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OBJECT.fields_by_name['pose'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
_OBJECT.fields_by_name['linear_velocity'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_OBJECT.fields_by_name['angular_velocity'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_OBJECT.fields_by_name['shape'].message_type = bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2._SHAPE
_OBJECT.fields_by_name['classification'].message_type = _OBJECT_CLASSIFICATION
_OBJECT.fields_by_name['path'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {

  'Classification' : _reflection.GeneratedProtocolMessageType('Classification', (_message.Message,), {

    'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
      'DESCRIPTOR' : _OBJECT_CLASSIFICATION_TYPE,
      '__module__' : 'bf_proto.percept.data.object_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object.Classification.Type)
      })
    ,
    'DESCRIPTOR' : _OBJECT_CLASSIFICATION,
    '__module__' : 'bf_proto.percept.data.object_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object.Classification)
    })
  ,
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'bf_proto.percept.data.object_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object)
  })
_sym_db.RegisterMessage(Object)
_sym_db.RegisterMessage(Object.Classification)
_sym_db.RegisterMessage(Object.Classification.Type)


# @@protoc_insertion_point(module_scope)
