"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.metadata_pb2
import bf_proto.percept.data.object_pb2
import bf_proto.percept.data.point_cloud_transform_pb2
import bf_proto.percept.data.state_pb2
import bf_proto.percept.data.zone_algorithm_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class StateList(google.protobuf.message.Message):
    """*
    A message containing one or more states.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    STATES_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    @property
    def states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.state_pb2.State]:
        """List of states."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        states : typing.Optional[typing.Iterable[bf_proto.percept.data.state_pb2.State]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"states",b"states"]) -> None: ...
global___StateList = StateList

class ObjectList(google.protobuf.message.Message):
    """*
    A message that can contain one or more objects.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    REFERENCE_FRAME_FIELD_NUMBER: builtins.int
    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    reference_frame: typing.Text = ...
    """The reference frame the geometry is expressed in."""

    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.object_pb2.Object]:
        """List of objects."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        reference_frame : typing.Text = ...,
        objects : typing.Optional[typing.Iterable[bf_proto.percept.data.object_pb2.Object]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"objects",b"objects",u"reference_frame",b"reference_frame"]) -> None: ...
global___ObjectList = ObjectList

class ZoneAlgorithmList(google.protobuf.message.Message):
    """*
    A message containing one or more zone algorithms.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    REFERENCE_FRAME_FIELD_NUMBER: builtins.int
    ZONE_ALGORITHMS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    reference_frame: typing.Text = ...
    """The reference frame of the zone geometry is expressed in."""

    @property
    def zone_algorithms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.zone_algorithm_pb2.ZoneAlgorithm]:
        """List of zones algorithms."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        reference_frame : typing.Text = ...,
        zone_algorithms : typing.Optional[typing.Iterable[bf_proto.percept.data.zone_algorithm_pb2.ZoneAlgorithm]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"reference_frame",b"reference_frame",u"zone_algorithms",b"zone_algorithms"]) -> None: ...
global___ZoneAlgorithmList = ZoneAlgorithmList

class PointCloudTransformList(google.protobuf.message.Message):
    """*
    A message containing one or more point cloud transformations.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    POINT_CLOUD_TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    @property
    def point_cloud_transforms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.point_cloud_transform_pb2.PointCloudTransform]: ...
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        point_cloud_transforms : typing.Optional[typing.Iterable[bf_proto.percept.data.point_cloud_transform_pb2.PointCloudTransform]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"point_cloud_transforms",b"point_cloud_transforms"]) -> None: ...
global___PointCloudTransformList = PointCloudTransformList
