# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/zone_algorithm.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometric_shapes_pb2 as bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2
from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/zone_algorithm.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*bf_proto/percept/data/zone_algorithm.proto\x12\x16\x62lickfeld.percept.data\x1a.bf_proto/percept/common/geometric_shapes.proto\x1a&bf_proto/percept/common/geometry.proto\"\x8e\x07\n\rZoneAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12.\n\x05shape\x18\x03 \x01(\x0b\x32\x1f.blickfeld.percept.common.Shape\x12^\n\x17\x63urrent_objects_counter\x18\x04 \x01(\x0b\x32;.blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounterH\x00\x12X\n\x14pass_through_counter\x18\x05 \x01(\x0b\x32\x38.blickfeld.percept.data.ZoneAlgorithm.PassThroughCounterH\x00\x12p\n appearance_disappearance_counter\x18\x06 \x01(\x0b\x32\x44.blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounterH\x00\x12\x42\n\x08security\x18\x07 \x01(\x0b\x32..blickfeld.percept.data.ZoneAlgorithm.SecurityH\x00\x12\x44\n\toccupancy\x18\x08 \x01(\x0b\x32/.blickfeld.percept.data.ZoneAlgorithm.OccupancyH\x00\x12>\n\x06volume\x18\t \x01(\x0b\x32,.blickfeld.percept.data.ZoneAlgorithm.VolumeH\x00\x1a\x17\n\x15\x43urrentObjectsCounter\x1a_\n\x12PassThroughCounter\x12/\n\x07inbound\x18\x01 \x01(\x0b\x32\x1e.blickfeld.percept.common.Axis\x12\x18\n\x10\x61\x63\x63umulate_count\x18\x02 \x01(\x08\x1a:\n\x1e\x41ppearanceDisappearanceCounter\x12\x18\n\x10\x61\x63\x63umulate_count\x18\x01 \x01(\x08\x1a\x1e\n\x08Security\x12\x12\n\nmin_points\x18\x01 \x01(\r\x1a\x1f\n\tOccupancy\x12\x12\n\nmin_points\x18\x01 \x01(\r\x1a\x32\n\x06Volume\x12\x12\n\nresolution\x18\x01 \x01(\x02\x12\x14\n\x0c\x65mpty_volume\x18\x02 \x01(\x02\x42\x10\n\x0e\x61lgorithm_typeb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_ZONEALGORITHM_CURRENTOBJECTSCOUNTER = _descriptor.Descriptor(
  name='CurrentObjectsCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=777,
)

_ZONEALGORITHM_PASSTHROUGHCOUNTER = _descriptor.Descriptor(
  name='PassThroughCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inbound', full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter.inbound', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulate_count', full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter.accumulate_count', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=874,
)

_ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER = _descriptor.Descriptor(
  name='AppearanceDisappearanceCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accumulate_count', full_name='blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter.accumulate_count', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=934,
)

_ZONEALGORITHM_SECURITY = _descriptor.Descriptor(
  name='Security',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Security',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_points', full_name='blickfeld.percept.data.ZoneAlgorithm.Security.min_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=966,
)

_ZONEALGORITHM_OCCUPANCY = _descriptor.Descriptor(
  name='Occupancy',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Occupancy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_points', full_name='blickfeld.percept.data.ZoneAlgorithm.Occupancy.min_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=999,
)

_ZONEALGORITHM_VOLUME = _descriptor.Descriptor(
  name='Volume',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Volume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='blickfeld.percept.data.ZoneAlgorithm.Volume.resolution', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='empty_volume', full_name='blickfeld.percept.data.ZoneAlgorithm.Volume.empty_volume', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1051,
)

_ZONEALGORITHM = _descriptor.Descriptor(
  name='ZoneAlgorithm',
  full_name='blickfeld.percept.data.ZoneAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blickfeld.percept.data.ZoneAlgorithm.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='blickfeld.percept.data.ZoneAlgorithm.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='blickfeld.percept.data.ZoneAlgorithm.shape', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_objects_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.current_objects_counter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_through_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.pass_through_counter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appearance_disappearance_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.appearance_disappearance_counter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security', full_name='blickfeld.percept.data.ZoneAlgorithm.security', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='blickfeld.percept.data.ZoneAlgorithm.occupancy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='blickfeld.percept.data.ZoneAlgorithm.volume', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ZONEALGORITHM_CURRENTOBJECTSCOUNTER, _ZONEALGORITHM_PASSTHROUGHCOUNTER, _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER, _ZONEALGORITHM_SECURITY, _ZONEALGORITHM_OCCUPANCY, _ZONEALGORITHM_VOLUME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='algorithm_type', full_name='blickfeld.percept.data.ZoneAlgorithm.algorithm_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=159,
  serialized_end=1069,
)

_ZONEALGORITHM_CURRENTOBJECTSCOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_PASSTHROUGHCOUNTER.fields_by_name['inbound'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._AXIS
_ZONEALGORITHM_PASSTHROUGHCOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_SECURITY.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_OCCUPANCY.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_VOLUME.containing_type = _ZONEALGORITHM
_ZONEALGORITHM.fields_by_name['shape'].message_type = bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2._SHAPE
_ZONEALGORITHM.fields_by_name['current_objects_counter'].message_type = _ZONEALGORITHM_CURRENTOBJECTSCOUNTER
_ZONEALGORITHM.fields_by_name['pass_through_counter'].message_type = _ZONEALGORITHM_PASSTHROUGHCOUNTER
_ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'].message_type = _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER
_ZONEALGORITHM.fields_by_name['security'].message_type = _ZONEALGORITHM_SECURITY
_ZONEALGORITHM.fields_by_name['occupancy'].message_type = _ZONEALGORITHM_OCCUPANCY
_ZONEALGORITHM.fields_by_name['volume'].message_type = _ZONEALGORITHM_VOLUME
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['current_objects_counter'])
_ZONEALGORITHM.fields_by_name['current_objects_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['pass_through_counter'])
_ZONEALGORITHM.fields_by_name['pass_through_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'])
_ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['security'])
_ZONEALGORITHM.fields_by_name['security'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['occupancy'])
_ZONEALGORITHM.fields_by_name['occupancy'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['volume'])
_ZONEALGORITHM.fields_by_name['volume'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
DESCRIPTOR.message_types_by_name['ZoneAlgorithm'] = _ZONEALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ZoneAlgorithm = _reflection.GeneratedProtocolMessageType('ZoneAlgorithm', (_message.Message,), {

  'CurrentObjectsCounter' : _reflection.GeneratedProtocolMessageType('CurrentObjectsCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_CURRENTOBJECTSCOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounter)
    })
  ,

  'PassThroughCounter' : _reflection.GeneratedProtocolMessageType('PassThroughCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_PASSTHROUGHCOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter)
    })
  ,

  'AppearanceDisappearanceCounter' : _reflection.GeneratedProtocolMessageType('AppearanceDisappearanceCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter)
    })
  ,

  'Security' : _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_SECURITY,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Security)
    })
  ,

  'Occupancy' : _reflection.GeneratedProtocolMessageType('Occupancy', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_OCCUPANCY,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Occupancy)
    })
  ,

  'Volume' : _reflection.GeneratedProtocolMessageType('Volume', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_VOLUME,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Volume)
    })
  ,
  'DESCRIPTOR' : _ZONEALGORITHM,
  '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm)
  })
_sym_db.RegisterMessage(ZoneAlgorithm)
_sym_db.RegisterMessage(ZoneAlgorithm.CurrentObjectsCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.PassThroughCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.AppearanceDisappearanceCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.Security)
_sym_db.RegisterMessage(ZoneAlgorithm.Occupancy)
_sym_db.RegisterMessage(ZoneAlgorithm.Volume)


# @@protoc_insertion_point(module_scope)
