# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/frame.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2
from blickfeld.config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from blickfeld.data import scanline_pb2 as blickfeld_dot_data_dot_scanline__pb2
from blickfeld.data import algorithm_pb2 as blickfeld_dot_data_dot_algorithm__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/frame.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x62lickfeld/data/frame.proto\x12\x17\x62lickfeld.protocol.data\x1a\x17\x62lickfeld/options.proto\x1a#blickfeld/config/scan_pattern.proto\x1a\x1d\x62lickfeld/data/scanline.proto\x1a\x1e\x62lickfeld/data/algorithm.proto\"\x8e\x05\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x1b\n\rstart_time_ns\x18\x03 \x01(\x04\x42\x04\xb0\xb5\x18\x01\x12\x42\n\x0cscan_pattern\x18\x05 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x12\x1e\n\x10is_ramp_up_phase\x18\t \x01(\x08\x42\x04\xb0\xb5\x18\x01\x12\x1e\n\x16total_number_of_points\x18\x06 \x01(\r\x12\x1f\n\x17total_number_of_returns\x18\x07 \x01(\r\x12:\n\tscanlines\x18\x02 \x03(\x0b\x32!.blickfeld.protocol.data.ScanlineB\x04\xb0\xb5\x18\x01\x12;\n\x06packed\x18\x08 \x01(\x0b\x32%.blickfeld.protocol.data.Frame.PackedB\x04\xb0\xb5\x18\x01\x12\x36\n\nalgorithms\x18\n \x03(\x0b\x32\".blickfeld.protocol.data.Algorithm\x1a\x85\x02\n\x06Packed\x12\x0e\n\x06length\x18\x01 \x01(\r\x12\x17\n\tcartesian\x18\x02 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\tdirection\x18\x03 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x13\n\x05range\x18\x04 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\tintensity\x18\x05 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12!\n\x13\x61mbient_light_level\x18\x06 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fstart_offset_ns\x18\x07 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x16\n\x08point_id\x18\x08 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x18\n\nchannel_id\x18\t \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\treturn_id\x18\n \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x42\x03\xf8\x01\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_data_dot_scanline__pb2.DESCRIPTOR,blickfeld_dot_data_dot_algorithm__pb2.DESCRIPTOR,])




_FRAME_PACKED = _descriptor.Descriptor(
  name='Packed',
  full_name='blickfeld.protocol.data.Frame.Packed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='blickfeld.protocol.data.Frame.Packed.length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cartesian', full_name='blickfeld.protocol.data.Frame.Packed.cartesian', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='blickfeld.protocol.data.Frame.Packed.direction', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='blickfeld.protocol.data.Frame.Packed.range', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='blickfeld.protocol.data.Frame.Packed.intensity', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ambient_light_level', full_name='blickfeld.protocol.data.Frame.Packed.ambient_light_level', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_offset_ns', full_name='blickfeld.protocol.data.Frame.Packed.start_offset_ns', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_id', full_name='blickfeld.protocol.data.Frame.Packed.point_id', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='blickfeld.protocol.data.Frame.Packed.channel_id', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_id', full_name='blickfeld.protocol.data.Frame.Packed.return_id', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=835,
)

_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='blickfeld.protocol.data.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.data.Frame.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.Frame.start_time_ns', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.data.Frame.scan_pattern', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ramp_up_phase', full_name='blickfeld.protocol.data.Frame.is_ramp_up_phase', index=3,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_number_of_points', full_name='blickfeld.protocol.data.Frame.total_number_of_points', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_number_of_returns', full_name='blickfeld.protocol.data.Frame.total_number_of_returns', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanlines', full_name='blickfeld.protocol.data.Frame.scanlines', index=6,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed', full_name='blickfeld.protocol.data.Frame.packed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='algorithms', full_name='blickfeld.protocol.data.Frame.algorithms', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FRAME_PACKED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=835,
)

_FRAME_PACKED.containing_type = _FRAME
_FRAME.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_FRAME.fields_by_name['scanlines'].message_type = blickfeld_dot_data_dot_scanline__pb2._SCANLINE
_FRAME.fields_by_name['packed'].message_type = _FRAME_PACKED
_FRAME.fields_by_name['algorithms'].message_type = blickfeld_dot_data_dot_algorithm__pb2._ALGORITHM
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), {

  'Packed' : _reflection.GeneratedProtocolMessageType('Packed', (_message.Message,), {
    'DESCRIPTOR' : _FRAME_PACKED,
    '__module__' : 'blickfeld.data.frame_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame.Packed)
    })
  ,
  'DESCRIPTOR' : _FRAME,
  '__module__' : 'blickfeld.data.frame_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame)
  })
_sym_db.RegisterMessage(Frame)
_sym_db.RegisterMessage(Frame.Packed)


DESCRIPTOR._options = None
_FRAME_PACKED.fields_by_name['cartesian']._options = None
_FRAME_PACKED.fields_by_name['direction']._options = None
_FRAME_PACKED.fields_by_name['range']._options = None
_FRAME_PACKED.fields_by_name['intensity']._options = None
_FRAME_PACKED.fields_by_name['ambient_light_level']._options = None
_FRAME_PACKED.fields_by_name['start_offset_ns']._options = None
_FRAME_PACKED.fields_by_name['point_id']._options = None
_FRAME_PACKED.fields_by_name['channel_id']._options = None
_FRAME_PACKED.fields_by_name['return_id']._options = None
_FRAME.fields_by_name['start_time_ns']._options = None
_FRAME.fields_by_name['scan_pattern']._options = None
_FRAME.fields_by_name['is_ramp_up_phase']._options = None
_FRAME.fields_by_name['scanlines']._options = None
_FRAME.fields_by_name['packed']._options = None
# @@protoc_insertion_point(module_scope)
