# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/common/geometric_shapes.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/common/geometric_shapes.proto',
  package='blickfeld.percept.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.bf_proto/percept/common/geometric_shapes.proto\x12\x18\x62lickfeld.percept.common\x1a&bf_proto/percept/common/geometry.proto\"\xb5\x01\n\x05Shape\x12,\n\x04pose\x18\x01 \x01(\x0b\x32\x1e.blickfeld.percept.common.Pose\x12\x32\n\x03\x62ox\x18\x02 \x01(\x0b\x32#.blickfeld.percept.common.Shape.BoxH\x00\x1a<\n\x03\x42ox\x12\x35\n\ndimensions\x18\x01 \x01(\x0b\x32!.blickfeld.percept.common.Vector3B\x0c\n\nshape_typeb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_SHAPE_BOX = _descriptor.Descriptor(
  name='Box',
  full_name='blickfeld.percept.common.Shape.Box',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='blickfeld.percept.common.Shape.Box.dimensions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=284,
)

_SHAPE = _descriptor.Descriptor(
  name='Shape',
  full_name='blickfeld.percept.common.Shape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='blickfeld.percept.common.Shape.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box', full_name='blickfeld.percept.common.Shape.box', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SHAPE_BOX, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='shape_type', full_name='blickfeld.percept.common.Shape.shape_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117,
  serialized_end=298,
)

_SHAPE_BOX.fields_by_name['dimensions'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_SHAPE_BOX.containing_type = _SHAPE
_SHAPE.fields_by_name['pose'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
_SHAPE.fields_by_name['box'].message_type = _SHAPE_BOX
_SHAPE.oneofs_by_name['shape_type'].fields.append(
  _SHAPE.fields_by_name['box'])
_SHAPE.fields_by_name['box'].containing_oneof = _SHAPE.oneofs_by_name['shape_type']
DESCRIPTOR.message_types_by_name['Shape'] = _SHAPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Shape = _reflection.GeneratedProtocolMessageType('Shape', (_message.Message,), {

  'Box' : _reflection.GeneratedProtocolMessageType('Box', (_message.Message,), {
    'DESCRIPTOR' : _SHAPE_BOX,
    '__module__' : 'bf_proto.percept.common.geometric_shapes_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Shape.Box)
    })
  ,
  'DESCRIPTOR' : _SHAPE,
  '__module__' : 'bf_proto.percept.common.geometric_shapes_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Shape)
  })
_sym_db.RegisterMessage(Shape)
_sym_db.RegisterMessage(Shape.Box)


# @@protoc_insertion_point(module_scope)
