"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HardwareVariant(_HardwareVariant, metaclass=_HardwareVariantEnumTypeWrapper):
    """do NOT change enum labels, they are used as strings in code"""
    pass
class _HardwareVariant:
    V = typing.NewType('V', builtins.int)
class _HardwareVariantEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HardwareVariant.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    ALL_HARDWARE = HardwareVariant.V(5)
    UNKNOWN_HARDWARE = HardwareVariant.V(6)
    NO_HARDWARE = HardwareVariant.V(7)
    CUBE_V0_2 = HardwareVariant.V(0)
    CUBE_V0_3 = HardwareVariant.V(1)
    CUBE_V1_0 = HardwareVariant.V(4)
    AURORA_P3 = HardwareVariant.V(3)
    APOLLON_A0 = HardwareVariant.V(2)
    APOLLON_A1_BDU = HardwareVariant.V(8)

ALL_HARDWARE = HardwareVariant.V(5)
UNKNOWN_HARDWARE = HardwareVariant.V(6)
NO_HARDWARE = HardwareVariant.V(7)
CUBE_V0_2 = HardwareVariant.V(0)
CUBE_V0_3 = HardwareVariant.V(1)
CUBE_V1_0 = HardwareVariant.V(4)
AURORA_P3 = HardwareVariant.V(3)
APOLLON_A0 = HardwareVariant.V(2)
APOLLON_A1_BDU = HardwareVariant.V(8)
global___HardwareVariant = HardwareVariant


class partial_trenz_eeprom_msg(google.protobuf.message.Message):
    """partial parse of trenz_eeprom_msg"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HARDWARE_VARIANT_FIELD_NUMBER: builtins.int
    hardware_variant: global___HardwareVariant.V = ...
    def __init__(self,
        *,
        hardware_variant : typing.Optional[global___HardwareVariant.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"hardware_variant",b"hardware_variant"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hardware_variant",b"hardware_variant"]) -> None: ...
global___partial_trenz_eeprom_msg = partial_trenz_eeprom_msg

class partial_module_eeprom_msg(google.protobuf.message.Message):
    """partial parse of {ldm,scanner,msb}_eeprom_msg"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HARDWARE_VERSION_FIELD_NUMBER: builtins.int
    hardware_version: typing.Text = ...
    def __init__(self,
        *,
        hardware_version : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"hardware_version",b"hardware_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hardware_version",b"hardware_version"]) -> None: ...
global___partial_module_eeprom_msg = partial_module_eeprom_msg
