# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/point_cloud_transform.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/point_cloud_transform.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1bf_proto/percept/data/point_cloud_transform.proto\x12\x16\x62lickfeld.percept.data\x1a&bf_proto/percept/common/geometry.proto\"m\n\x13PointCloudTransform\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\x36\n\ttransform\x18\x03 \x01(\x0b\x32#.blickfeld.percept.common.Transformb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_POINTCLOUDTRANSFORM = _descriptor.Descriptor(
  name='PointCloudTransform',
  full_name='blickfeld.percept.data.PointCloudTransform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='blickfeld.percept.data.PointCloudTransform.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.percept.data.PointCloudTransform.target', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform', full_name='blickfeld.percept.data.PointCloudTransform.transform', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=226,
)

_POINTCLOUDTRANSFORM.fields_by_name['transform'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._TRANSFORM
DESCRIPTOR.message_types_by_name['PointCloudTransform'] = _POINTCLOUDTRANSFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloudTransform = _reflection.GeneratedProtocolMessageType('PointCloudTransform', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUDTRANSFORM,
  '__module__' : 'bf_proto.percept.data.point_cloud_transform_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.PointCloudTransform)
  })
_sym_db.RegisterMessage(PointCloudTransform)


# @@protoc_insertion_point(module_scope)
