"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.common_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Client(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LIBRARY_VERSION_FIELD_NUMBER: builtins.int
    FILE_TIME_NS_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    library_version: typing.Text = ...
    """Library version"""

    file_time_ns: builtins.int = ...
    """Unit: [ns] - File time stamp"""

    language: blickfeld.common_pb2.Language.V = ...
    """Used library language for file creation"""

    def __init__(self,
        *,
        library_version : typing.Optional[typing.Text] = ...,
        file_time_ns : typing.Optional[builtins.int] = ...,
        language : typing.Optional[blickfeld.common_pb2.Language.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"file_time_ns",b"file_time_ns",u"language",b"language",u"library_version",b"library_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"file_time_ns",b"file_time_ns",u"language",b"language",u"library_version",b"library_version"]) -> None: ...
global___Client = Client
