"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Secure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Permissions(_Permissions, metaclass=_PermissionsEnumTypeWrapper):
        """do NOT change enum labels, they are used as strings in ssl certs"""
        pass
    class _Permissions:
        V = typing.NewType('V', builtins.int)
    class _PermissionsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Permissions.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        PUBLIC = Secure.Permissions.V(0)
        DEVELOPER = Secure.Permissions.V(1)

    PUBLIC = Secure.Permissions.V(0)
    DEVELOPER = Secure.Permissions.V(1)

    class CertType(_CertType, metaclass=_CertTypeEnumTypeWrapper):
        pass
    class _CertType:
        V = typing.NewType('V', builtins.int)
    class _CertTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CertType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        CLIENT = Secure.CertType.V(0)
        CUBE = Secure.CertType.V(1)

    CLIENT = Secure.CertType.V(0)
    CUBE = Secure.CertType.V(1)

    PERMISSIONS_FIELD_NUMBER: builtins.int
    CERT_TYPE_FIELD_NUMBER: builtins.int
    VERSION_MAJOR_FIELD_NUMBER: builtins.int
    VERSION_MINOR_FIELD_NUMBER: builtins.int
    VERSION_PATCH_FIELD_NUMBER: builtins.int
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Secure.Permissions.V]: ...
    cert_type: global___Secure.CertType.V = ...
    version_major: builtins.int = ...
    version_minor: builtins.int = ...
    version_patch: builtins.int = ...
    def __init__(self,
        *,
        permissions : typing.Optional[typing.Iterable[global___Secure.Permissions.V]] = ...,
        cert_type : typing.Optional[global___Secure.CertType.V] = ...,
        version_major : typing.Optional[builtins.int] = ...,
        version_minor : typing.Optional[builtins.int] = ...,
        version_patch : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"cert_type",b"cert_type",u"version_major",b"version_major",u"version_minor",b"version_minor",u"version_patch",b"version_patch"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"cert_type",b"cert_type",u"permissions",b"permissions",u"version_major",b"version_major",u"version_minor",b"version_minor",u"version_patch",b"version_patch"]) -> None: ...
global___Secure = Secure
