"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.geometry_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PointCloudTransform(google.protobuf.message.Message):
    """*
    A message that contains point cloud transformation information
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TRANSFORM_FIELD_NUMBER: builtins.int
    source: typing.Text = ...
    """Source frame of the point cloud. This corresponds to user-defined name of the lidar."""

    target: typing.Text = ...
    """Target frame of the transform"""

    @property
    def transform(self) -> bf_proto.percept.common.geometry_pb2.Transform:
        """Rigid transformation"""
        pass
    def __init__(self,
        *,
        source : typing.Text = ...,
        target : typing.Text = ...,
        transform : typing.Optional[bf_proto.percept.common.geometry_pb2.Transform] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"transform",b"transform"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"source",b"source",u"target",b"target",u"transform",b"transform"]) -> None: ...
global___PointCloudTransform = PointCloudTransform
