# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/output/output.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import metadata_pb2 as bf__proto_dot_percept_dot_common_dot_metadata__pb2
from bf_proto.percept.data import object_pb2 as bf__proto_dot_percept_dot_data_dot_object__pb2
from bf_proto.percept.data import state_pb2 as bf__proto_dot_percept_dot_data_dot_state__pb2
from bf_proto.percept.data import zone_algorithm_pb2 as bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2
from bf_proto.percept.data import point_cloud_transform_pb2 as bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/output/output.proto',
  package='blickfeld.percept.output',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$bf_proto/percept/output/output.proto\x12\x18\x62lickfeld.percept.output\x1a&bf_proto/percept/common/metadata.proto\x1a\"bf_proto/percept/data/object.proto\x1a!bf_proto/percept/data/state.proto\x1a*bf_proto/percept/data/zone_algorithm.proto\x1a\x31\x62\x66_proto/percept/data/point_cloud_transform.proto\"s\n\tStateList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.blickfeld.percept.data.State\"\x8f\x01\n\nObjectList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12/\n\x07objects\x18\x03 \x03(\x0b\x32\x1e.blickfeld.percept.data.Object\"\xa5\x01\n\x11ZoneAlgorithmList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12>\n\x0fzone_algorithms\x18\x03 \x03(\x0b\x32%.blickfeld.percept.data.ZoneAlgorithm\"\x9f\x01\n\x17PointCloudTransformList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12K\n\x16point_cloud_transforms\x18\x02 \x03(\x0b\x32+.blickfeld.percept.data.PointCloudTransformb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_metadata__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_object__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_state__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2.DESCRIPTOR,])




_STATELIST = _descriptor.Descriptor(
  name='StateList',
  full_name='blickfeld.percept.output.StateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.StateList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='blickfeld.percept.output.StateList.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=387,
)


_OBJECTLIST = _descriptor.Descriptor(
  name='ObjectList',
  full_name='blickfeld.percept.output.ObjectList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.ObjectList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_frame', full_name='blickfeld.percept.output.ObjectList.reference_frame', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects', full_name='blickfeld.percept.output.ObjectList.objects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=533,
)


_ZONEALGORITHMLIST = _descriptor.Descriptor(
  name='ZoneAlgorithmList',
  full_name='blickfeld.percept.output.ZoneAlgorithmList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.ZoneAlgorithmList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_frame', full_name='blickfeld.percept.output.ZoneAlgorithmList.reference_frame', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_algorithms', full_name='blickfeld.percept.output.ZoneAlgorithmList.zone_algorithms', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=701,
)


_POINTCLOUDTRANSFORMLIST = _descriptor.Descriptor(
  name='PointCloudTransformList',
  full_name='blickfeld.percept.output.PointCloudTransformList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.PointCloudTransformList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud_transforms', full_name='blickfeld.percept.output.PointCloudTransformList.point_cloud_transforms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=863,
)

_STATELIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_STATELIST.fields_by_name['states'].message_type = bf__proto_dot_percept_dot_data_dot_state__pb2._STATE
_OBJECTLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_OBJECTLIST.fields_by_name['objects'].message_type = bf__proto_dot_percept_dot_data_dot_object__pb2._OBJECT
_ZONEALGORITHMLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_ZONEALGORITHMLIST.fields_by_name['zone_algorithms'].message_type = bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2._ZONEALGORITHM
_POINTCLOUDTRANSFORMLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_POINTCLOUDTRANSFORMLIST.fields_by_name['point_cloud_transforms'].message_type = bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2._POINTCLOUDTRANSFORM
DESCRIPTOR.message_types_by_name['StateList'] = _STATELIST
DESCRIPTOR.message_types_by_name['ObjectList'] = _OBJECTLIST
DESCRIPTOR.message_types_by_name['ZoneAlgorithmList'] = _ZONEALGORITHMLIST
DESCRIPTOR.message_types_by_name['PointCloudTransformList'] = _POINTCLOUDTRANSFORMLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StateList = _reflection.GeneratedProtocolMessageType('StateList', (_message.Message,), {
  'DESCRIPTOR' : _STATELIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.StateList)
  })
_sym_db.RegisterMessage(StateList)

ObjectList = _reflection.GeneratedProtocolMessageType('ObjectList', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.ObjectList)
  })
_sym_db.RegisterMessage(ObjectList)

ZoneAlgorithmList = _reflection.GeneratedProtocolMessageType('ZoneAlgorithmList', (_message.Message,), {
  'DESCRIPTOR' : _ZONEALGORITHMLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.ZoneAlgorithmList)
  })
_sym_db.RegisterMessage(ZoneAlgorithmList)

PointCloudTransformList = _reflection.GeneratedProtocolMessageType('PointCloudTransformList', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUDTRANSFORMLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.PointCloudTransformList)
  })
_sym_db.RegisterMessage(PointCloudTransformList)


# @@protoc_insertion_point(module_scope)
