"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Product(_Product, metaclass=_ProductEnumTypeWrapper):
    """*
    Product variant
    """
    pass
class _Product:
    V = typing.NewType('V', builtins.int)
class _ProductEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Product.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PRODUCT_CUBE = Product.V(0)
    PRODUCT_CUBE_RANGE = Product.V(2)

PRODUCT_CUBE = Product.V(0)
PRODUCT_CUBE_RANGE = Product.V(2)
global___Product = Product

