"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IMU(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.18 and firmware v1.19

    This section defines the status of the IMU.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class StaticState(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ACCELERATION_FIELD_NUMBER: builtins.int
        @property
        def acceleration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
        def __init__(self,
            *,
            acceleration : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"acceleration",b"acceleration"]) -> None: ...

    STATIC_STATE_FIELD_NUMBER: builtins.int
    @property
    def static_state(self) -> global___IMU.StaticState: ...
    def __init__(self,
        *,
        static_state : typing.Optional[global___IMU.StaticState] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"static_state",b"static_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"static_state",b"static_state"]) -> None: ...
global___IMU = IMU
